vsutillib.media package
=======================

.. _MediaFileInfo:

The ``MediaFileInfo`` class
---------------------------

.. autoclass:: vsutillib.media.MediaFileInfo
    :members:

The ``MediaTrackInfo`` class
----------------------------

.. autoclass:: vsutillib.media.MediaTrackInfo
    :members:

The ``isMediaInfoLib`` function
-------------------------------

.. autofunction:: vsutillib.media.isMediaInfoLib
